@@ -1,10 +1,11 @@
+import numpy as np
+
 from gptcache.utils import import_cohere
+from gptcache.embedding.base import BaseEmbedding
+
 import_cohere()
 
-import numpy as np
-import cohere
-
-from .base import BaseEmbedding
+import cohere  # pylint: disable=C0413
 
 
 class Cohere(BaseEmbedding):
@@ -19,12 +20,13 @@ class Cohere(BaseEmbedding):
         .. code-block:: python
 
             from gptcache.embedding import Cohere
-            
-            test_sentence = 'Hello, world.' 
+
+            test_sentence = 'Hello, world.'
             encoder = Cohere(model='small', api_key='your_cohere_key')
             embed = encoder.to_embeddings(test_sentence)
     """
-    def __init__(self, model: str='large', api_key: str=None, **kwargs):
+
+    def __init__(self, model: str = "large", api_key: str = None):
         self.co = cohere.Client(api_key)
         self.model = model
 
@@ -32,8 +34,8 @@ class Cohere(BaseEmbedding):
             self.__dimension = self.dim_dict()[model]
         else:
             self.__dimension = None
-    
-    def to_embeddings(self, data):
+
+    def to_embeddings(self, data, **_):
         """Generate embedding given text input
 
         :param data: text in string.
@@ -45,7 +47,7 @@ class Cohere(BaseEmbedding):
             data = [data]
         response = self.co.embed(texts=data, model=self.model)
         embeddings = response.embeddings
-        return np.array(embeddings).astype('float32').squeeze(0)
+        return np.array(embeddings).astype("float32").squeeze(0)
 
     @property
     def dimension(self):
@@ -54,13 +56,10 @@ class Cohere(BaseEmbedding):
         :return: embedding dimension
         """
         if not self.__dimension:
-            foo_emb = self.to_embeddings('foo')
+            foo_emb = self.to_embeddings("foo")
             self.__dimension = len(foo_emb)
         return self.__dimension
-    
+
     @staticmethod
     def dim_dict():
-        return {
-            'large': 4096,
-            'small': 1024
-        }
+        return {"large": 4096, "small": 1024}
