@@ -8,12 +8,14 @@ class ClearStrategy(Enum):
 
 
 class VectorBase(ABC):
+    """VectorBase: base vector store interface"""
+
     @abstractmethod
-    def add(self, key: str, data: 'ndarray'):
+    def add(self, key: str, data: "ndarray"):
         pass
 
     @abstractmethod
-    def search(self, data: 'ndarray'):
+    def search(self, data: "ndarray"):
         pass
 
     @abstractmethod
